SuperNotificationFlutterBeta class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

httpRequestManager ↔ HttpRequestManager
getter/setter pair

Static Methods

actionRequest(String action) Future<void>
getPlatformVersion() Future<String?>
initialize(String baseurl, String apikey, String deviceId) Future<void>
initializeNotification() Future<void>
initializeWorkManager() Future<void>
requestNotificationPermission() Future<void>
showNotification(String title, String body, String click_action) Future<void>